summaryrefslogtreecommitdiffstats
path: root/akregator/src/akregator_part.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-14 20:16:30 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-14 20:16:30 +0000
commit1c93fca14d9ce37499bcfdf994c660186a0b6f17 (patch)
treef2defe163a805a9e34a2142dfde4cdb5e49241e7 /akregator/src/akregator_part.cpp
parent67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (diff)
downloadtdepim-1c93fca14d9ce37499bcfdf994c660186a0b6f17.tar.gz
tdepim-1c93fca14d9ce37499bcfdf994c660186a0b6f17.zip
Enable kdepim compilation under Qt4
This will likely break Qt3 compilation temporarily, which is an unintended side effect. A third and final kdepim commit will repair Qt3 compilation shortly. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227946 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'akregator/src/akregator_part.cpp')
-rw-r--r--akregator/src/akregator_part.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/akregator/src/akregator_part.cpp b/akregator/src/akregator_part.cpp
index 2b0f73e7..3cdbceb1 100644
--- a/akregator/src/akregator_part.cpp
+++ b/akregator/src/akregator_part.cpp
@@ -54,7 +54,7 @@
#include <tqstringlist.h>
#include <tqtimer.h>
#include <tqwidgetlist.h>
-#include <private/qucomextra_p.h>
+#include <private/tqucomextra_p.h>
#include <cerrno>
#include <sys/types.h>
@@ -146,7 +146,7 @@ Part::Part( TQWidget *tqparentWidget, const char * /*widgetName*/,
TQStringList storageParams;
- storageParams.append(TQString("taggingEnabled=%1").arg(Settings::showTaggingGUI() ? "true" : "false"));
+ storageParams.append(TQString("taggingEnabled=%1").tqarg(Settings::showTaggingGUI() ? "true" : "false"));
if (factory != 0)
{
@@ -168,7 +168,7 @@ Part::Part( TQWidget *tqparentWidget, const char * /*widgetName*/,
{
m_storage = Backend::StorageFactoryRegistry::self()->getFactory("dummy")->createStorage(storageParams);
- KMessageBox::error(tqparentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").arg(Settings::archiveBackend()), i18n("Plugin error") );
+ KMessageBox::error(tqparentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").tqarg(Settings::archiveBackend()), i18n("Plugin error") );
}
Filters::ArticleFilterList list;
@@ -232,7 +232,7 @@ Part::Part( TQWidget *tqparentWidget, const char * /*widgetName*/,
initFonts();
- RSS::FileRetriever::setUserAgent(TQString("Akregator/%1; librss/remnants").arg(AKREGATOR_VERSION));
+ RSS::FileRetriever::setUserAgent(TQString("Akregator/%1; librss/remnants").tqarg(AKREGATOR_VERSION));
}
void Part::loadPlugins()
@@ -432,7 +432,7 @@ bool Part::openFile()
copyFile(backup);
- KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("XML Parsing Error") );
+ KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").tqarg(backup), i18n("XML Parsing Error") );
}
if (!doc.setContent(listBackup))
@@ -447,7 +447,7 @@ bool Part::openFile()
TQString backup = m_file + "-backup." + TQString::number(TQDateTime::tqcurrentDateTime().toTime_t());
copyFile(backup);
- KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("OPML Parsing Error") );
+ KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").tqarg(backup), i18n("OPML Parsing Error") );
}
m_view->loadFeeds(createDefaultFeedList());
}
@@ -486,7 +486,7 @@ void Part::slotSaveFeedList()
if (file.open(IO_WriteOnly) == false)
{
//FIXME: allow to save the feedlist into different location -tpr 20041118
- KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").arg(m_file), i18n("Write error") );
+ KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").tqarg(m_file), i18n("Write error") );
return;
}
@@ -522,7 +522,7 @@ bool Part::mergePart(KParts::Part* part)
{
if (m_mergedPart) {
factory()->removeClient(m_mergedPart);
- if (childClients()->containsRef(m_mergedPart))
+ if (childClients()->tqcontainsRef(m_mergedPart))
removeChildClient(m_mergedPart);
}
if (part)
@@ -575,7 +575,7 @@ void Part::loadTagSet(const TQString& path)
TQFile file(path);
if (file.open(IO_ReadOnly))
{
- doc.setContent(file.readAll());
+ doc.setContent(TQByteArray(file.readAll()));
file.close();
}
// if we can't load the tagset from the xml file, check for the backup in the backend
@@ -636,13 +636,13 @@ void Part::importFile(const KURL& url)
{
// Read OPML feeds list and build TQDom tree.
TQDomDocument doc;
- if (doc.setContent(file.readAll()))
+ if (doc.setContent(TQByteArray(file.readAll())))
m_view->importFeeds(doc);
else
- KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").arg(filename), i18n("OPML Parsing Error") );
+ KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").tqarg(filename), i18n("OPML Parsing Error") );
}
else
- KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").arg(filename), i18n("Read Error"));
+ KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").tqarg(filename), i18n("Read Error"));
if (isRemote)
KIO::NetAccess::removeTempFile(filename);
@@ -656,7 +656,7 @@ void Part::exportFile(const KURL& url)
if ( file.exists() &&
KMessageBox::questionYesNo(m_view,
- i18n("The file %1 already exists; do you want to overwrite it?").arg(file.name()),
+ i18n("The file %1 already exists; do you want to overwrite it?").tqarg(file.name()),
i18n("Export"),
i18n("Overwrite"),
KStdGuiItem::cancel()) == KMessageBox::No )
@@ -664,7 +664,7 @@ void Part::exportFile(const KURL& url)
if ( !file.open(IO_WriteOnly) )
{
- KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").arg(file.name()), i18n("Write Error") );
+ KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").tqarg(file.name()), i18n("Write Error") );
return;
}
@@ -978,11 +978,11 @@ bool Part::tryToLock(const TQString& backendName)
"can cause the loss of archived articles and crashes at startup.</b> "
"You should disable the archive for now "
"unless you are sure that %2 is not already running.</qt>")
- .arg( programName, programName, backendName );
+ .tqarg( programName, programName, backendName );
// TQString::arg( st ) only replaces the first occurrence of %1
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
// even think about changing the above to .arg( programName ).
else
msg = i18n("<qt>%1 seems to be running on another display on this "
"machine. <b>Running %1 and %2 at the same "
@@ -990,7 +990,7 @@ bool Part::tryToLock(const TQString& backendName)
"the loss of archived articles and crashes at startup.</b> "
"You should disable the archive for now "
"unless you are sure that %2 is not already running.</qt>")
- .arg( oldProgramName, programName, backendName );
+ .tqarg( oldProgramName, programName, backendName );
}
else
{
@@ -1001,7 +1001,7 @@ bool Part::tryToLock(const TQString& backendName)
"You should disable the archive for now "
"unless you are sure that it is "
"not already running on %2.</qt>")
- .arg( programName, oldHostName, backendName );
+ .tqarg( programName, oldHostName, backendName );
else
msg = i18n("<qt>%1 seems to be running on %3. <b>Running %1 and %2 at the "
"same time is not supported by the %4 backend and can cause "
@@ -1009,7 +1009,7 @@ bool Part::tryToLock(const TQString& backendName)
"You should disable the archive for now "
"unless you are sure that %1 is "
"not running on %3.</qt>")
- .arg( oldProgramName, programName, oldHostName, backendName );
+ .tqarg( oldProgramName, programName, oldHostName, backendName );
}
KCursorSaver idle( KBusyPtr::idle() );
@@ -978,11 +978,11 @@ bool Part::tryToLock(const TQString& backendName)
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
- // even think about changing the above to .arg( programName ).
+ // even think about changing the above to .tqarg( programName ).
else
msg = i18n("<qt>%1 seems to be running on another display on this "